#!/bin/bash
#
# Script to remove some files from one or several user accounts. The
# removed files can either be destroyed immediately (option --remove-old)
# or may be renamed adding the .old suffix, with existing .old files destroyed.
#
# The files removed may be the configuration files related to kde (--kde),
# gnome (--gnome), or netscape (--netscape), or all the configuration files
# (--config), all the non-configuration files (--data), or all files (--all).

function usage() {
    echo "reset-account [--remove-old] [--kde] [--gnome] [--netscape]"
    echo "    [--config] [--data] [--all] -- user1 user2..."
}

FILES=""
FILTER="*.old"
KEEP_OLD="TRUE"

for i in $*; do
    OPTION="$1"
    shift
    case "$OPTION" in
	--remove-old)
	    KEEP_OLD=""
	    FILTER="";;

	--kde)
	    FILES=".kde*";;

	--gnome)
	    FILES=".gnome*";;

	--config)
	    FILES=".*";;

	--netscape)
	    FILES=".netscape";;

	--data)
	    FILES="[^.]*";;

	--all)
	    FILES="*";;

	--)
	    break;;

	*|--help)
	    usage
	    exit;;
    esac
done

for user in $*; do
    echo "Resetting account for user $user"
    HOMEUSER=`eval echo ~$user`
    cd $HOMEUSER
    if [ `pwd` == "$HOMEUSER" ]; then
        for file in `ls -A`; do
	    if [[ "$file" == $FILES && "$file" != $FILTER ]]; then
		if [ -n "$KEEP_OLD" ]; then
		    rm -fr ${file}.old
		    mv ${file} ${file}.old
		else
		    rm -fr ${file}
		fi
	    fi
	done
    else
	echo "Cannot list home of $user"
    fi
done

