#!/bin/sh
XTPATH=/xterminals/root
if [ ! -d $XTPATH  ] ; then
	echo X terminals runtime environment not installed yet: $XTPATH
	echo aborting
	exit 1
fi
cd /usr/lib/xtermkit
mkdir -p /var/xterminals
echo /usr/X11R6/lib >$XTPATH/etc/ld.so.conf
export PATH=/sbin:/bin:/usr/sbin:/usr/bin
chroot $XTPATH /sbin/ldconfig
cp /etc/resolv.conf $XTPATH/etc

install -o root -g root -m 644 fstab.xterm $XTPATH/etc/fstab
rm -fr $XTPATH/etc/sysconfig
ln -sf X11/sysconfig $XTPATH/etc/sysconfig
ln -sf /etc/X11/conf.modules $XTPATH/etc/conf.modules
rm -fr $XTPATH/tmp
ln -sf /etc/X11/tmp $XTPATH/tmp
rm -fr $XTPATH/usr/X11R6/lib/X11/fs
mkdir $XTPATH/usr/X11R6/lib/X11/fs
cat >$XTPATH/usr/X11R6/lib/X11/fs/config <<-EOF
catalogue = /usr/X11R6/lib/X11/fonts/misc:unscaled,
	/usr/X11R6/lib/X11/fonts/75dpi:unscaled,
	/usr/X11R6/lib/X11/fonts/misc,
	/usr/X11R6/lib/X11/fonts/Type1,
	/usr/X11R6/lib/X11/fonts/Speedo,
	/usr/X11R6/lib/X11/fonts/75dpi,
	/usr/share/fonts/default/Type1
EOF
rm -fr $XTPATH/usr/X11R6/lib/X11/xkb
mkdir -p $XTPATH/usr/X11R6/lib/X11/xkb/compiled
mkdir -p $XTPATH/lib/modules
mkdir -p $XTPATH/etc/xterminit.d
ln -sf /etc/rc.d/init.d/snmpd $XTPATH/etc/xterminit.d/snmpd
mkdir -p $XTPATH/etc/xtermrc.d
cp -a kernels/modules/* $XTPATH/lib/modules/.
install commands/xgo -o root -g root -m 755 $XTPATH/bin/xgo
install commands/rc  -o root -g root -m 755 $XTPATH/etc/rc
install commands/rc.sh  -o root -g root -m 755 $XTPATH/etc/rc.sh
install commands/getmac  -o root -g root -m 755 $XTPATH/bin/
install commands/initdev  -o root -g root -m 755 $XTPATH/etc/initdev
install commands/xconf -o root -g root -m 755 $XTPATH/bin/xconf
install commands/swapconf -o root -g root -m 755 $XTPATH/bin/
install commands/cdromconf -o root -g root -m 755 $XTPATH/bin/
install commands/soundconf -o root -g root -m 755 $XTPATH/bin/
install commands/setname  -o root -g root -m 755 $XTPATH/bin/
install commands/enable-swap -o root -g root -m 755 $XTPATH/sbin/enable-swap
install commands/getdefserver -o root -g root -m 755 $XTPATH/sbin/getdefserver
install commands/printserv -o root -g root -m 755 $XTPATH/sbin/printserv
install commands/printconf -o root -g root -m 755 $XTPATH/bin/printconf
install commands/copysetup -o root -g root -m 755 $XTPATH/bin/copysetup
install commands/getrefdir -o root -g root -m 755 $XTPATH/bin/getrefdir
install commands/Xautoconfig -o root -g root -m 755 $XTPATH/bin
install commands/enable-swap -o root -g root -m 755 $XTPATH/bin
install commands/enable-boot -o root -g root -m 755 $XTPATH/bin
cat conf.tar.gz | gunzip | (cd $XTPATH/bin && tar xf -)
if [ -f stuff/linuxconf-lib*.rpm ] ; then
	rpm --root $XTPATH -Uvh stuff/linuxconf-lib*rpm
fi
if [ -f stuff/openslp*.rpm ] ; then
	rpm --root $XTPATH -Uvh stuff/openslp*rpm
fi
mkdir -p $XTPATH/usr/lib/xtermkit/kernels
install commands/ProbeNames $XTPATH/usr/lib/xtermkit
install linux.bat $XTPATH/usr/lib/xtermkit
install loadlin.exe $XTPATH/usr/lib/xtermkit
rm -f $XTPATH/usr/lib/xtermkit/kernels/kernel-2.2
cp -a kernels/. $XTPATH/usr/lib/xtermkit/kernels/.

# Install a default X terminal configuration is missing
if [ ! -d /var/xterminals/preferred ] ; then
	cat preferred.tar.gz | gunzip | (cd /var/xterminals && tar xf - )
fi

# We will try to find out if it is an old installation with IP numbers
# in /var/xterminals
USINGIP=0
if [ -d /var/xterminals ]; then
	cd /var/xterminals
	for i in * stuff
	do
		case $i in
		[0-9]*.[0-9]*.[0-9]*.[0-9]*)
			USINGIP=1
			;;
		esac
	done
fi
if [ "$USINGIP" = 0 ] ; then
	touch $XTPATH/etc/USE_MAC_ADDRESS
fi
mkdir -p $XTPATH/mnt/xterminals
echo
echo X terminals runtime environment /xterminals/root updated
if [ ! -f $XTPATH/usr/lib/liblinuxconf.so.1 ] ; then
	echo
	echo "The package linuxconf-lib is not installed."
	echo "The kit can't work without it."
	echo "Pick it from http://www.solucorp.qc.ca/linuxconf/download.hc"
	echo "Pick the version for redhat-6, since this is how we compiled"
	echo "xtermkit"
	echo
fi

