#!/bin/sh
# This will make sure the server is ready to handle X terminals
# The following services will be configured
# NFS
# DHCPD
# xdm/kdm/gdm
# font server
backup(){
	if [ -f $1/$2 ] ; then
		if [ -x /usr/bin/ci ] ; then
			ci $1/$2 <<-EOF >/dev/null 2>/dev/null
			.
			EOF
			rcs -U $1/$2 >/dev/null 2>/dev/null
			co $1/$2 >/dev/null 2>/dev/null
			mv $1/$2 $1/$2.last
			echo "	" $1/$2 was archived using RCS.
			echo "	" To get the original, do
			echo "		" co $1/$2
		elif [ ! "$1/$2".original ] ; then
			cp $1/$2 $1/$2.original
			cp -a $1/$2 $1/$2.last
			echo $1/$2 was backuped to $2.original
		else
			cp -a $1/$2 $1/$2.last
		fi
	fi
}

nfsexport(){
	echo Checking NFS configuration
	backup /etc exports
	if [ ! -f /etc/exports.last ] ; then
		echo "/xterminals/root (ro)" >>/etc/exports
		echo "/var/xterminals/root (rw,no_root_squash)" >>/etc/exports
		echo file /etc/exports was created
	else
		mv /etc/exports.last /etc/exports
		NB=`grep /xterminals/root /etc/exports | wc -l`
		NB=`expr $NB`
		if [ "$NB" != 1 ] ;then
			echo "	" Adding entry for /xterminals/root
			echo "/xterminals/root (ro)" >>/etc/exports
		else
			echo "	" There is already an entry for /xterminals/root
		fi
		NB=`grep /var/xterminals /etc/exports | wc -l`
		NB=`expr $NB`
		if [ "$NB" != 1 ] ;then
			echo "	" Adding entry for /var/xterminals
			echo "/var/xterminals (rw,no_root_squash)" >>/etc/exports
		else
			echo "	" There is already an entry for /var/xterminals
		fi
		echo File /etc/exports was checked/updated
	fi
}
nfsservice(){
	echo Checking NFS service
	NB=`rpm -q nfs-utils 2>/dev/null | wc -l`
	NB=`expr $NB`
	if [ "$NB" != 1 ] ; then
		echo The NFS server package is not installed. You need
		echo to install the nfs-utils package.
		echo
		/bin/echo -n Do you want to do it now " ? (y/n) "
		read yes
		if [ "$yes" = "y" ] ; then
			echo -n Insert you RedHat/Mandrake cdrom and press enter
			read a
			mount /mnt/cdrom 2>/dev/null
			if [ -d /mnt/cdrom/RedHat/RPMS ] ; then
				rpm -Uvh /mnt/cdrom/RedHat/RPMS/nfs-utils*rpm
			elif [ -d /mnt/cdrom/Mandrake/RPMS ] ; then
				rpm -Uvh /mnt/cdrom/Mandrake/RPMS/nfs-utils*rpm
			else
				echo "Can't locate the Cdrom"
			fi
		fi
	fi
	NB=`rpm -q nfs-utils 2>/dev/null | wc -l`
	NB=`expr $NB`
	if [ "$NB" = 1 ] ; then
		echo Enabling the NFS service now and starting it
		/sbin/chkconfig --level 345 nfs on
		/sbin/chkconfig --level 345 nfslock on
		/etc/rc.d/init.d/nfs restart
	fi
}
dhcpconfig(){
	echo Checking DHCP configuration
	if [ -f /etc/dhcpd.conf ] ; then
		echo "	" File /etc/dhcpd.conf already exist
		echo "	" Not modified
	else
		backup /etc dhcpd.conf
		echo We will now configure the dhcp server. We need
		echo a configuration for every network on which you intend
		echo to put X terminals.
		echo server-identifier `hostname`\; >>/etc/dhcpd.conf
		while true
		do
			/bin/echo -n "Domain name (ex somedomain.com) : "
			read domain
			/bin/echo -n "Domain name server (DNS) : "
			read dns
			/bin/echo -n "Network number (ex 192.168.1.0) : "
			read network
			/bin/echo -n "Netmask (ex: 255.255.255.0) : "
			read netmask
			/bin/echo -n "First IP number available (ex: 192.168.1.100) : "
			read start
			/bin/echo -n "Last IP number available  (ex: 192.168.1.254) : "
			read end
			/bin/echo -n "Gateway  (ex: 192.168.1.10) : "
			read gtw
			echo subnet $network netmask $netmask { >> /etc/dhcpd.conf
			echo "	" "range dynamic-bootp $start $end;" >>/etc/dhcpd.conf
			echo "	" "routers $gtw;" >>/etc/dhcpd.conf
			echo "	" "option domain-name	\"$domain\";" >>/etc/dhcpd.conf
			echo "	" "option domain-name-servers	$dns;" >>/etc/dhcpd.conf
			echo } >>/etc/dhcpd.conf
			echo
			/bin/echo -n "Another network to configure ? (y/n) "
			read yes
			if [ "$yes" != "y" ] ; then
				break
			fi
		done
	fi
	mkdir -p /var/lib/dhcp
	touch /var/lib/dhcp/dhcpd.leases
}
dhcpservice(){
	echo Checking DHCP service
	NB=`rpm -q dhcp 2>/dev/null | wc -l`
	NB=`expr $NB`
	if [ "$NB" != 1 ] ; then
		echo The DHCP server package is not installed. You need
		echo to install the dhcp package.
		echo
		/bin/echo -n Do you want to do it now " ? (y/n) "
		read yes
		if [ "$yes" = "y" ] ; then
			echo "(On RedHat 7.0, insert disk 2)"
			echo -n Insert you RedHat/Mandrake cdrom and press enter
			read a
			mount /mnt/cdrom 2>/dev/null
			if [ -d /mnt/cdrom/RedHat/RPMS ] ; then
				rpm -Uvh /mnt/cdrom/RedHat/RPMS/dhcp-*rpm
			elif [ -d /mnt/cdrom/Mandrake/RPMS ] ; then
				rpm -Uvh /mnt/cdrom/Mandrake/RPMS/dhcp-*rpm
			else
				echo "Can't locate the Cdrom"
			fi
		fi
	fi
	NB=`rpm -q dhcp 2>/dev/null | wc -l`
	NB=`expr $NB`
	if [ "$NB" = 1 ] ; then
		echo Enabling the DHCP service now and starting it
		/sbin/chkconfig --level 345 dhcpd on
		/etc/rc.d/init.d/dhcpd restart
	fi
}

xfsconfig(){
	echo Checking font server
	if [ ! -f /etc/X11/fs/config ] ; then
		echo the font server is not installed on this server
	else
		cd /etc/X11/fs
		backup /etc/X11/fs config
		grep -v no-listen config.last >config
		echo "# no-listen = tcp" >>config
		echo Font server configured
	fi
}
xdmconfig(){
	echo Checking KDE/X display manager
	if [ ! -f /etc/X11/xdm/Xaccess ] ; then
		echo X or KDE display manager not installed
	else
		cd /etc/X11/xdm
		backup /etc/X11/xdm Xaccess
		echo "* #any host can get a login window" >Xaccess
		grep -v "any host can get a login window" <Xaccess.last >>Xaccess
		backup /etc/X11/xdm xdm-config
		grep -v DisplayManager.requestPort xdm-config.last >xdm-config
		echo "#DisplayManager.requestPort:    0" >>xdm-config
	fi
}
gdmconfig(){
	echo Checking Gnome display manager
	if [ ! -f /etc/X11/gdm/gdm.conf ] ; then
		echo Gnome display manager is not installed
	else
		cd /etc/X11/gdm
		backup /etc/X11/gdm gdm.conf
		>gdm.conf
		cat gdm.conf.last | while read line
		do
			case $line in
			\[xdmcp\])
				xdmcp=1
				;;
			\[*\])
				xdmcp=0
				;;
			Enable=*)
				if [ "$xdmcp" = 1 ] ; then	
					line="Enable=1"
				fi
			esac
			echo $line >>gdm.conf
		done
	fi
}
if [ $# = 0 ] ;then
	# Check everything
	$0 nfs
	$0 dhcp
	$0 xfs
	$0 xdm
elif [ "$1" = "nfs" ] ; then
	nfsexport
	nfsservice
elif [ "$1" = "xfs" ] ; then
	xfsconfig
elif [ "$1" = "dhcp" ] ; then
	echo Checking DHCP server
	dhcpconfig
	dhcpservice
elif [ "$1" = "xdm" ] ; then
	echo "Checking X display manager (graphical login)"
	xdmconfig
	gdmconfig
else
	echo setup-server.sh "[ nfs | dhcp | xfs | xdm ]"
	exit 1
fi

