#!/bin/sh
# This script will install the basic framework to support linux based
# X terminal
ROOT=/xterminals/root
RPMDB=$ROOT/var/lib/rpm
install_fromcd(){
	RPMS=$1
	suffix=$2
	rpmoptions=$3
	uselinuxconf=$4
	if [ ! -d $RPMS ] ; then
		echo $RPMS does not exist
	else
		mkdir -p $RPMDB
		echo rpm --root $ROOT --initdb
		for i in `cat pkgs/packages-$suffix.lst pkgs/servers-$suffix.lst`
		do
			NB=`ls $RPMS/$i-[0-9]*.i386.rpm 2>/dev/null | wc -l`
			NB=`expr $NB`
			#echo $RPMS/$i-[0-9]*.i386.rpm "->" :$NB:
			if [ "$NB" != "1" ] ; then
				NB=`ls $RPMS/$i-[0-9]*.noarch.rpm 2>/dev/null | wc -l` 
				NB=`expr $NB`
				if [ "$NB" != "1" ] ; then
					NB=`ls $RPMS/$i-[0-9]*.i586.rpm 2>/dev/null | wc -l` 
					NB=`expr $NB`
					if [ "$NB" != "1" ] ; then
						echo Missing or ambiguous package $i
						err=1
					else
						PKG=$RPMS/$i-[0-9]*.i586.rpm
						if [ "$USELINUXCONF" = "" ] ; then
							echo Will install $PKG
						fi
						LIST="$LIST $PKG"
					fi
				else
					PKG=$RPMS/$i-[0-9]*.noarch.rpm
					echo Will install $PKG
					LIST="$LIST $PKG"
				fi
			else
				PKG=$RPMS/$i-[0-9]*.i386.rpm
				echo Will install $PKG
				LIST="$LIST $PKG"
			fi
		done
		if [ "$err" != "" ] ; then
			echo One package missing, aborting
		else
			#echo LIST=$LIST
			if [ "$USELINUXCONF" != "" ] ; then
				rpm --root $ROOT --initdb
				linuxconf --modulemain managerpm --root /xterminals/root \
					--update $rpmoptions $LIST
			else
				rpm --noscripts --root $ROOT -ivh $LIST $rpmoptions
			fi
			touch /xterminals/root/configuring
		fi
	fi
}

if [ -d $ROOT ] ; then
	echo The xterminals framework is already installed in /xterminals/root >&2
	echo Aborting... >&2
elif [ $# = 0 ] ; then
	# Interactive mode
	rpmoptions=""
	echo
	echo "                  Linux based X terminals"
	echo "                  Server side installation"
	echo
	echo "                 " 1=Redhat 6.2 CD
	echo "                 " 2=Redhat 7.0 CD
	echo "                 " 3=Redhat 7.1 CD
	echo "                 " 4=Mandrake 8.0 CD
	echo
	echo -n "                  Choice ? "
	read ch
	DIR=RedHat/RPMS
	if [ "$ch" = "1" ] ; then
		suffix=redhat6.2
		rpmoptions="--nodeps"
	elif [ "$ch" = "2" ] ; then
		suffix=redhat7.0
	elif [ "$ch" = "3" ] ; then
		suffix=redhat7.1
		rpmoptions="--nodeps"
	elif [ "$ch" = "4" ] ; then
		suffix=mandrake8.0
		DIR=Mandrake/RPMS
	else
		echo Invalid choice
		exit
	fi
	echo
	echo -n "Enter the path of the $suffix cdrom [/mnt/cdrom] : "
	read RHPATH
	if [ "$RHPATH" = "" ] ; then
		RHPATH=/mnt/cdrom
	fi
	RPMS=$RHPATH/$DIR
	install_fromcd $RPMS $suffix $rpmoptions
	if [ "$suffix" = "redhat7.1" ] ; then
		echo
		echo Attention: Do not forget to install redhat updates
		echo for packages mouseconfig and Xconfigurator
		echo
		echo Download them from ftp://updates.redhat.com/7.1/en/os/i386
		echo and install them by doing
		echo
		echo rpm --root /xterminals/root -Uvh mouseconfig-4.22-1.i386.rpm
		echo "            " Xconfigurator-4.9.29-1.i386.rpm
		echo
	fi
elif [ "$1" = "--customcd" -a $# -ge 2 ] ; then
	# The argument is a directory containing the required packages
	mkdir -p $RPMDB
	echo rpm --root $ROOT --initdb
	DIR=$2
	shift
	shift
	rpm --noscripts --root $ROOT -ivh $DIR/*.rpm $*
	touch /xterminals/root/configuring
elif [ "$1" = "--noprompt" -a $# -ge 2 ] ; then
	cd /usr/lib/xtermkit
	RPMS=/mnt/cdrom/RedHat/RPMS
	SUFFIX=redhat6.2
	RPMOPTIONS=
	USELINUXCONF=
	shift
	while [ $# != 0 ]
	do
		if [ "$1" = "--RPMS" ] ; then
			RPMS=$2
			shift
			shift
		elif [ "$1" = "--SUFFIX" ] ; then
			SUFFIX=$2
			shift
			shift
		elif [ "$1" = "--RPMOPTIONS" ] ; then
			RPMOPTIONS=$2
			shift
			shift
		elif [ "$1" = "--USELINUXCONF" ] ; then
			USELINUXCONF=1
			shift
		else
			echo Invalid option >&2
			exit 1
		fi
	done
	install_fromcd $RPMS $SUFFIX $RPMOPTIONS $USELINUXCONF
fi

